@@ -176,7 +176,7 @@ droute_add_one (DRouteContext *cnx,
     DRoutePath *new_path;
     gboolean registered;
 
-    new_path = path_new (cnx, NULL, NULL, (void *) data, NULL);
+    new_path = path_new (cnx, (void *)data, NULL, NULL, NULL);
 
     registered = dbus_connection_register_object_path (cnx->bus, path, &droute_vtable, new_path);
     if (!registered)
